@@ -10,7 +10,7 @@
 ### Pripominky, opravy chyb a nove prispevky vlastni i nalezene muzete
 ###  posilat na adresu <zdenekZAVpytela.net>.
 
-VERZE="2.0"
+VERZE="2.0.9"
 FORTUNE="/usr/bin/fortune"
 STRFILE="/usr/sbin/strfile"
 STRFILEALT="/usr/bin/strfile"
@@ -36,7 +36,7 @@ DOCDIR=$PREFIX${DOCDIR-"/usr/share/doc/fortune-cs-$VERZE"}
 ### Kde je adresar s texty fortunes (FHS 2.0)
 FORTUNESDIR=$PREFIX${FORTUNESDIR:-"/usr/share/games/fortune"}
 
-### wish skript fortune.tk
+### dialog scripts go into /usr/games
 GAMESDIR=$PREFIX/usr/games
 APPSDIR=$PREFIX/usr/share/applications
 PIXMAPDIR=$PREFIX/usr/share/pixmaps
@@ -69,9 +69,11 @@ then
   exit 4
 fi
 
-### wish skript, odkaz pro menu, ikonka
-install -d $GAMESDIR \
-&& install -m755 src/fortune-cs.tk $GAMESDIR
+### dialog skripty, odkaz pro menu, ikonka
+if install -d $GAMESDIR; then
+ install -m755 src/fortune-cs.tk $GAMESDIR
+ install -m755 src/fortune-cs.sh $GAMESDIR
+fi
 install -d $APPSDIR \
 && install -m644 src/fortune-cs.desktop $APPSDIR
 install -d $PIXMAPDIR \
